@@ -7,11 +7,11 @@
 
 use crate::{
     config::NextestProfile,
+    list::{TestInstance, TestList},
     reporter::{CancelReason, StatusLevel, TestEvent},
     signal::{SignalEvent, SignalHandler},
     stopwatch::{StopwatchEnd, StopwatchStart},
     target_runner::TargetRunner,
-    test_list::{TestInstance, TestList},
 };
 use crossbeam_channel::{RecvTimeoutError, Sender};
 use nextest_metadata::{FilterMatch, MismatchReason};
@@ -343,7 +343,7 @@ impl<'a> TestRunner<'a> {
         run_sender: &Sender<InternalTestEvent<'a>>,
     ) -> std::io::Result<InternalExecuteStatus> {
         let cmd = test
-            .make_expression(&self.target_runner)
+            .make_expression(self.test_list, &self.target_runner)
             .unchecked()
             // Debug environment variable for testing.
             .env("__NEXTEST_ATTEMPT", format!("{}", attempt));
