@@ -6,17 +6,19 @@ use color_eyre::eyre::Result;
 use nextest_metadata::BuildPlatform;
 use nextest_runner::{
     config::NextestConfig,
+    list::BinaryList,
     runner::{ExecutionDescription, ExecutionResult, TestRunnerBuilder},
     signal::SignalHandler,
     target_runner::TargetRunner,
     test_filter::{RunIgnored, TestFilterBuilder},
-    test_list::{BinaryList, TestList},
 };
 use pretty_assertions::assert_eq;
 use std::io::Cursor;
 
 #[test]
 fn test_list_binaries() -> Result<()> {
+    set_rustflags();
+
     let graph = &*PACKAGE_GRAPH;
     let binary_list =
         BinaryList::from_messages(Cursor::new(&*FIXTURE_RAW_CARGO_TEST_OUTPUT), graph)?;
@@ -39,12 +41,14 @@ fn test_list_binaries() -> Result<()> {
 
 #[test]
 fn test_list_tests() -> Result<()> {
+    set_rustflags();
+
     let test_filter = TestFilterBuilder::any(RunIgnored::Default);
-    let test_bins: Vec<_> = FIXTURE_TARGETS.values().cloned().collect();
-    let test_list = TestList::new(test_bins, &test_filter, &TargetRunner::empty())?;
+    let test_list = FIXTURE_TARGETS.make_test_list(&test_filter, &TargetRunner::empty());
 
     for (name, expected) in &*EXPECTED_TESTS {
         let test_binary = FIXTURE_TARGETS
+            .test_artifacts
             .get(*name)
             .unwrap_or_else(|| panic!("unexpected test name {}", name));
         let info = test_list
@@ -63,9 +67,10 @@ fn test_list_tests() -> Result<()> {
 
 #[test]
 fn test_run() -> Result<()> {
+    set_rustflags();
+
     let test_filter = TestFilterBuilder::any(RunIgnored::Default);
-    let test_bins: Vec<_> = FIXTURE_TARGETS.values().cloned().collect();
-    let test_list = TestList::new(test_bins, &test_filter, &TargetRunner::empty())?;
+    let test_list = FIXTURE_TARGETS.make_test_list(&test_filter, &TargetRunner::empty());
     let config =
         NextestConfig::from_sources(&workspace_root(), None).expect("loaded fixture config");
     let profile = config
@@ -83,6 +88,7 @@ fn test_run() -> Result<()> {
 
     for (name, expected) in &*EXPECTED_TESTS {
         let test_binary = FIXTURE_TARGETS
+            .test_artifacts
             .get(*name)
             .unwrap_or_else(|| panic!("unexpected test name {}", name));
         for fixture in expected {
@@ -117,9 +123,10 @@ fn test_run() -> Result<()> {
 
 #[test]
 fn test_run_ignored() -> Result<()> {
+    set_rustflags();
+
     let test_filter = TestFilterBuilder::any(RunIgnored::IgnoredOnly);
-    let test_bins: Vec<_> = FIXTURE_TARGETS.values().cloned().collect();
-    let test_list = TestList::new(test_bins, &test_filter, &TargetRunner::empty())?;
+    let test_list = FIXTURE_TARGETS.make_test_list(&test_filter, &TargetRunner::empty());
     let config =
         NextestConfig::from_sources(&workspace_root(), None).expect("loaded fixture config");
     let profile = config
@@ -137,6 +144,7 @@ fn test_run_ignored() -> Result<()> {
 
     for (name, expected) in &*EXPECTED_TESTS {
         let test_binary = FIXTURE_TARGETS
+            .test_artifacts
             .get(*name)
             .unwrap_or_else(|| panic!("unexpected test name {}", name));
         for fixture in expected {
@@ -171,9 +179,10 @@ fn test_run_ignored() -> Result<()> {
 
 #[test]
 fn test_retries() -> Result<()> {
+    set_rustflags();
+
     let test_filter = TestFilterBuilder::any(RunIgnored::Default);
-    let test_bins: Vec<_> = FIXTURE_TARGETS.values().cloned().collect();
-    let test_list = TestList::new(test_bins, &test_filter, &TargetRunner::empty())?;
+    let test_list = FIXTURE_TARGETS.make_test_list(&test_filter, &TargetRunner::empty());
     let config =
         NextestConfig::from_sources(&workspace_root(), None).expect("loaded fixture config");
     let profile = config
@@ -194,6 +203,7 @@ fn test_retries() -> Result<()> {
 
     for (name, expected) in &*EXPECTED_TESTS {
         let test_binary = FIXTURE_TARGETS
+            .test_artifacts
             .get(*name)
             .unwrap_or_else(|| panic!("unexpected test name {}", name));
         for fixture in expected {
